==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/GridColumnsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnsChangedEventArgsDescription } from "./GridColumnsChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridColumnsChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnsChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnsChangedEventArgsDescriptionMetadata.a == null) {
                GridColumnsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnsChangedEventArgsDescriptionMetadata.c(GridColumnsChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(GridColumnsChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(GridColumnsChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Columns", "Collection:DataGridColumn:GridColumnCollection:DataGridColumn");
        }
        static d(a) {
            GridColumnsChangedEventArgsDescriptionMetadata.b(a);
            a.aa("GridColumnsChangedEventArgs", () => new GridColumnsChangedEventArgsDescription());
            a.z("GridColumnsChangedEventArgs", GridColumnsChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridColumnsChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnsChangedEventArgsDescriptionMetadata, 'GridColumnsChangedEventArgsDescriptionMetadata');
    GridColumnsChangedEventArgsDescriptionMetadata.a = null;
    return GridColumnsChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GridColumnsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnsChangedEventArgsDescription } from "./GridColumnsChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridColumnsChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnsChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnsChangedEventArgsDescriptionMetadata.a == null) {
                GridColumnsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnsChangedEventArgsDescriptionMetadata.c(GridColumnsChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridColumnsChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(GridColumnsChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Columns", "Collection:DataGridColumn:GridColumnCollection:DataGridColumn");
        }
        static d(a) {
            GridColumnsChangedEventArgsDescriptionMetadata.b(a);
            a.ac("GridColumnsChangedEventArgs", () => new GridColumnsChangedEventArgsDescription());
            a.ab("GridColumnsChangedEventArgs", GridColumnsChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridColumnsChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnsChangedEventArgsDescriptionMetadata, 'GridColumnsChangedEventArgsDescriptionMetadata');
    GridColumnsChangedEventArgsDescriptionMetadata.a = null;
    return GridColumnsChangedEventArgsDescriptionMetadata;
})();
